diff --git b/core/modules/file/file.field.inc a/core/modules/file/file.field.inc
index 6524c27..9d58d1d 100644
--- b/core/modules/file/file.field.inc
+++ a/core/modules/file/file.field.inc
@@ -20,7 +20,6 @@ function file_field_info() {
         'display_field' => 0,
         'display_default' => 0,
         'uri_scheme' => file_default_scheme(),
-        'translation_sync' => array('fid'),
       ),
       'instance_settings' => array(
         'file_extensions' => 'txt',
diff --git b/core/modules/image/image.field.inc a/core/modules/image/image.field.inc
index 1144fe3..11152ae 100644
--- b/core/modules/image/image.field.inc
+++ a/core/modules/image/image.field.inc
@@ -19,7 +19,20 @@ function image_field_info() {
       'settings' => array(
         'uri_scheme' => file_default_scheme(),
         'default_image' => 0,
-        'translation_sync' => array('fid'),
+        'column_groups' => array(
+          'file' => array(
+            'label' => t('File'),
+            'columns' => array('fid', 'width', 'height'),
+          ),
+          'alt' => array(
+            'label' => t('Alt'),
+            'translatable' => TRUE,
+          ),
+          'title' => array(
+            'label' => t('Title'),
+            'translatable' => TRUE,
+          ),
+        ),
       ),
       'instance_settings' => array(
         'file_extensions' => 'png gif jpg jpeg',
diff --git b/core/modules/language/language.admin.inc a/core/modules/language/language.admin.inc
index bdba951..a3500fd 100644
--- b/core/modules/language/language.admin.inc
+++ a/core/modules/language/language.admin.inc
@@ -1021,6 +1021,7 @@ function language_content_settings_form(array $form, array $form_state, array $s
     $form['settings'][$entity_type] = array(
       '#title' => $labels[$entity_type],
       '#type' => 'container',
+      '#entity_type' => $entity_type,
       '#theme' => 'language_content_settings_table',
       '#bundle_label' => isset($info['bundle_label']) ? $info['bundle_label'] : $labels[$entity_type],
       '#states' => array(
diff --git b/core/modules/translation_entity/lib/Drupal/translation_entity/FieldTranslationSynchronizer.php a/core/modules/translation_entity/lib/Drupal/translation_entity/FieldTranslationSynchronizer.php
index 94e80ec..281b82f 100644
--- b/core/modules/translation_entity/lib/Drupal/translation_entity/FieldTranslationSynchronizer.php
+++ a/core/modules/translation_entity/lib/Drupal/translation_entity/FieldTranslationSynchronizer.php
@@ -12,30 +12,12 @@
 /**
  * Provides field translation synchronization capabilities.
  */
-class FieldTranslationSynchronizer {
+class FieldTranslationSynchronizer implements FieldTranslationSynchronizerInterface {
 
   /**
-   * Performs field column synchronization on the given entity.
-   *
-   * Field column synchronization takes care of propagating any change in the
-   * field items order and in the column values themselves to all the available
-   * translations. This functionality is provided by defining a
-   * 'translation_sync' key in the field instance settings, holding an array of
-   * column names to be synchronized. The synchronized column values are shared
-   * across translations, while the rest varies per-language. This is useful for
-   * instance to translate the "alt" and "title" textual elements of an image
-   * field, while keeping the same image on every translation.
-   *
-   * @param \Drupal\Core\Entity\EntityInterface $entity
-   *   The entity whose values should be synchronized.
-   * @param string $sync_langcode
-   *   The language of the translation whose values should be used as source for
-   *   synchronization.
-   * @param string $original_langcode
-   *   (optional) If a new translation is being created, this should be the
-   *   language code of the original values. Defaults to NULL.
+   * Implements \Drupal\translation_entity\FieldTranslationSynchronizerInterface::synchronizeFields().
    */
-  public function synchronizeEntity(EntityInterface $entity, $sync_langcode, $original_langcode = NULL) {
+  public function synchronizeFields(EntityInterface $entity, $sync_langcode, $original_langcode = NULL) {
     $translations = $entity->getTranslationLanguages();
 
     // If we have no information about what to sync to, if we are creating a new
@@ -47,6 +29,8 @@ public function synchronizeEntity(EntityInterface $entity, $sync_langcode, $orig
 
     // If the entity language is being changed there is nothing to synchronize.
     $entity_type = $entity->entityType();
+    // @todo Use the entity storage controller directly to avoid accessing the
+    //   global scope.
     $entity_unchanged = isset($entity->original) ? $entity->original : entity_load_unchanged($entity_type, $entity->id());
     if ($entity->language()->langcode != $entity_unchanged->language()->langcode) {
       return;
@@ -63,39 +47,33 @@ public function synchronizeEntity(EntityInterface $entity, $sync_langcode, $orig
       // Sync when the field is not empty, when the synchronization translations
       // setting is set, and the field is translatable.
       if (!empty($entity->{$field_name}) && !empty($instance['settings']['translation_sync']) && field_is_translatable($entity_type, $field)) {
-        $columns = isset($field['settings']['translation_sync']) ? $field['settings']['translation_sync'] : array();
-        $source_items = $entity->{$field_name}[$sync_langcode];
-
-        // If a translation is being created, the original values should be used
-        // as the unchanged items. In fact there are no unchanged items to check
-        // against.
-        $langcode = $original_langcode ?: $sync_langcode;
-        $unchanged_items = !empty($entity_unchanged->{$field_name}[$langcode]) ? $entity_unchanged->{$field_name}[$langcode] : array();
-        $this->synchronizeField($entity->{$field_name}, $unchanged_items, $sync_langcode, array_keys($translations), $columns);
+        // Retrieve all the untranslatable column groups and merge them into
+        // single list.
+        $groups = array_keys(array_diff($instance['settings']['translation_sync'], array_filter($instance['settings']['translation_sync'])));
+        if (!empty($groups)) {
+          $columns = array();
+          foreach ($groups as $group) {
+            $info = $field['settings']['column_groups'][$group];
+            // A missing 'columns' key indicates we have a single-column group.
+            $columns = array_merge($columns, isset($info['columns']) ? $info['columns'] : array($group));
+          }
+          if (!empty($columns)) {
+            // If a translation is being created, the original values should be
+            // used as the unchanged items. In fact there are no unchanged items
+            // to check against.
+            $langcode = $original_langcode ?: $sync_langcode;
+            $unchanged_items = !empty($entity_unchanged->{$field_name}[$langcode]) ? $entity_unchanged->{$field_name}[$langcode] : array();
+            $this->synchronizeItems($entity->{$field_name}, $unchanged_items, $sync_langcode, array_keys($translations), $columns);
+          }
+        }
       }
     }
   }
 
   /**
-   * Synchronize the items of a single field.
-   *
-   * All the column values of the "active" language are compared to the
-   * unchanged values to detect any addition, removal or change in the items
-   * order. Subsequently the detected changes are performed on the field items
-   * in other available languages.
-   *
-   * @param array $field_values
-   *   The field values to be synchronized.
-   * @param array $unchanged_items
-   *   The unchanged items to be used to detect changes.
-   * @param string $sync_langcode
-   *   The language code of the items to use as source values.
-   * @param array $translations
-   *   An array of all the available language codes for the given field.
-   * @param array $columns
-   *   An array of column names to be synchronized.
+   * Implements \Drupal\translation_entity\FieldTranslationSynchronizerInterface::synchronizeItems().
    */
-  public function synchronizeField(array &$field_values, array $unchanged_items, $sync_langcode, array $translations, array $columns) {
+  public function synchronizeItems(array &$field_values, array $unchanged_items, $sync_langcode, array $translations, array $columns) {
     $source_items = $field_values[$sync_langcode];
 
     // Make sure we can detect any change in the source items.
diff --git b/core/modules/translation_entity/lib/Drupal/translation_entity/FieldTranslationSynchronizerInterface.php a/core/modules/translation_entity/lib/Drupal/translation_entity/FieldTranslationSynchronizerInterface.php
new file mode 100644
index 0000000..1ae361c
--- /dev/null
+++ a/core/modules/translation_entity/lib/Drupal/translation_entity/FieldTranslationSynchronizerInterface.php
@@ -0,0 +1,61 @@
+<?php
+
+/**
+ * @file
+ * Contains \Drupal\translation_entity\FieldTranslationSynchronizerInterface.
+ */
+
+namespace Drupal\translation_entity;
+
+use Drupal\Core\Entity\EntityInterface;
+
+/**
+ * Provides field translation synchronization capabilities.
+ */
+interface FieldTranslationSynchronizerInterface {
+
+  /**
+   * Performs field column synchronization on the given entity.
+   *
+   * Field column synchronization takes care of propagating any change in the
+   * field items order and in the column values themselves to all the available
+   * translations. This functionality is provided by defining a
+   * 'translation_sync' key in the field instance settings, holding an array of
+   * column names to be synchronized. The synchronized column values are shared
+   * across translations, while the rest varies per-language. This is useful for
+   * instance to translate the "alt" and "title" textual elements of an image
+   * field, while keeping the same image on every translation.
+   *
+   * @param \Drupal\Core\Entity\EntityInterface $entity
+   *   The entity whose values should be synchronized.
+   * @param string $sync_langcode
+   *   The language of the translation whose values should be used as source for
+   *   synchronization.
+   * @param string $original_langcode
+   *   (optional) If a new translation is being created, this should be the
+   *   language code of the original values. Defaults to NULL.
+   */
+  public function synchronizeFields(EntityInterface $entity, $sync_langcode, $original_langcode = NULL);
+
+  /**
+   * Synchronize the items of a single field.
+   *
+   * All the column values of the "active" language are compared to the
+   * unchanged values to detect any addition, removal or change in the items
+   * order. Subsequently the detected changes are performed on the field items
+   * in other available languages.
+   *
+   * @param array $field_values
+   *   The field values to be synchronized.
+   * @param array $unchanged_items
+   *   The unchanged items to be used to detect changes.
+   * @param string $sync_langcode
+   *   The language code of the items to use as source values.
+   * @param array $translations
+   *   An array of all the available language codes for the given field.
+   * @param array $columns
+   *   An array of column names to be synchronized.
+   */
+  public function synchronizeItems(array &$field_values, array $unchanged_items, $sync_langcode, array $translations, array $columns);
+
+}
diff --git b/core/modules/translation_entity/lib/Drupal/translation_entity/Tests/EntityTranslationSyncImageTest.php a/core/modules/translation_entity/lib/Drupal/translation_entity/Tests/EntityTranslationSyncImageTest.php
index c18c982..61f93cf 100644
--- b/core/modules/translation_entity/lib/Drupal/translation_entity/Tests/EntityTranslationSyncImageTest.php
+++ a/core/modules/translation_entity/lib/Drupal/translation_entity/Tests/EntityTranslationSyncImageTest.php
@@ -9,19 +9,11 @@
 
 use Drupal\Core\Entity\EntityInterface;
 use Drupal\Core\Language\Language;
-use Drupal\simpletest\WebTestBase;
 
 /**
  * Tests the Entity Translation image field synchronization capability.
  */
-class EntityTranslationSyncImageTest extends WebTestBase {
-
-  /**
-   * The name of the image field to test synchronization on.
-   *
-   * @var string
-   */
-  protected $fieldImageName;
+class EntityTranslationSyncImageTest extends EntityTranslationTestBase {
 
   /**
    * The cardinality of the image field.
@@ -31,11 +23,11 @@ class EntityTranslationSyncImageTest extends WebTestBase {
   protected $cardinality;
 
   /**
-   * The enabled languages.
+   * The test image files.
    *
    * @var array
    */
-  protected $langcodes;
+  protected $files;
 
   /**
    * Modules to enable.
@@ -54,41 +46,18 @@ public static function getInfo() {
 
   function setUp() {
     parent::setUp();
-
-    // Setup the test image field and the test files.
-    $this->setupImageField();
     $this->files = $this->drupalGetTestFiles('image');
-
-    // Enable translation for the test entity.
-    translation_entity_set_config('entity_test', 'entity_test', 'enabled', TRUE);
-    drupal_static_reset();
-    entity_info_cache_clear();
-    menu_router_rebuild();
-
-    // Setup the test user.
-    $user = $this->drupalCreateUser(array('administer entity_test content', 'translate any entity'));
-    $this->drupalLogin($user);
-
-    // Setup languages.
-    $this->langcodes = array('it', 'fr');
-    foreach ($this->langcodes as $langcode) {
-      language_save(new Language(array('langcode' => $langcode)));
-    }
-    array_unshift($this->langcodes, language_default()->langcode);
-
-    // Initialize the translation controller.
-    $this->controller = translation_entity_controller('entity_test');
   }
 
   /**
    * Creates the test image field.
    */
-  protected function setupImageField() {
-    $this->fieldImageName = 'field_test_et_ui_image';
+  protected function setupTestFields() {
+    $this->fieldName = 'field_test_et_ui_image';
     $this->cardinality = 3;
 
     $field = array(
-      'field_name' => $this->fieldImageName,
+      'field_name' => $this->fieldName,
       'type' => 'image',
       'cardinality' => $this->cardinality,
       'translatable' => TRUE,
@@ -96,16 +65,20 @@ protected function setupImageField() {
     field_create_field($field);
 
     $instance = array(
-      'entity_type' => 'entity_test',
-      'field_name' => $this->fieldImageName,
-      'bundle' => 'entity_test',
-      'label' => 'Test translatable imagefield',
+      'entity_type' => $this->entityType,
+      'field_name' => $this->fieldName,
+      'bundle' => $this->entityType,
+      'label' => 'Test translatable image field',
       'widget' => array(
         'type' => 'image_image',
         'weight' => 0,
       ),
       'settings' => array(
-        'translation_sync' => TRUE,
+        'translation_sync' => array(
+          'file' => FALSE,
+          'alt' => 'alt',
+          'title' => 'title',
+        ),
       ),
     );
     field_create_instance($instance);
@@ -129,7 +102,7 @@ function testImageFieldSync() {
       'user_id' => mt_rand(1, 128),
       'langcode' => $default_langcode,
     );
-    $entity = entity_create('entity_test', $values)->getBCEntity();
+    $entity = entity_create($this->entityType, $values)->getBCEntity();
 
     // Create some file entities from the generated test files and store them.
     $values = array();
@@ -156,7 +129,7 @@ function testImageFieldSync() {
         'alt' => $this->randomName(),
         'title' => $this->randomName(),
       );
-      $entity->{$this->fieldImageName}[$default_langcode][$delta] = $item;
+      $entity->{$this->fieldName}[$default_langcode][$delta] = $item;
 
       // Store the generated values keying them by fid for easier lookup.
       $values[$default_langcode][$fid] = $item;
@@ -181,7 +154,7 @@ function testImageFieldSync() {
         'alt' => $this->randomName(),
         'title' => $this->randomName(),
       );
-      $entity->{$this->fieldImageName}[$langcode][$delta] = $item;
+      $entity->{$this->fieldName}[$langcode][$delta] = $item;
 
       // Again store the generated values keying them by fid for easier lookup.
       $values[$langcode][$fid] = $item;
@@ -192,15 +165,15 @@ function testImageFieldSync() {
     $entity = $this->saveEntity($entity);
 
     // Check that one value has been dropped from the original values.
-    $assert = count($entity->{$this->fieldImageName}[$default_langcode]) == 2;
+    $assert = count($entity->{$this->fieldName}[$default_langcode]) == 2;
     $this->assertTrue($assert, 'One item correctly removed from the synchronized field values.');
 
     // Check that fids have been synchronized and translatable column values
     // have been retained.
     $fids = array();
-    foreach ($entity->{$this->fieldImageName}[$default_langcode] as $delta => $item) {
+    foreach ($entity->{$this->fieldName}[$default_langcode] as $delta => $item) {
       $value = $values[$default_langcode][$item['fid']];
-      $source_item = $entity->{$this->fieldImageName}[$langcode][$delta];
+      $source_item = $entity->{$this->fieldName}[$langcode][$delta];
       $assert = $item['fid'] == $source_item['fid'] && $item['alt'] == $value['alt'] && $item['title'] == $value['title'];
       $this->assertTrue($assert, format_string('Field item @fid has been successfully synchronized.', array('@fid' => $item['fid'])));
       $fids[$item['fid']] = TRUE;
@@ -219,20 +192,20 @@ function testImageFieldSync() {
       'alt' => $this->randomName(),
       'title' => $this->randomName(),
     );
-    $entity->{$this->fieldImageName}[$langcode] = array_values($values[$langcode]);
+    $entity->{$this->fieldName}[$langcode] = array_values($values[$langcode]);
     $entity = $this->saveEntity($entity);
 
     // Check that the value has been added to the default language.
-    $assert = count($entity->{$this->fieldImageName}[$default_langcode]) == 3;
+    $assert = count($entity->{$this->fieldName}[$default_langcode]) == 3;
     $this->assertTrue($assert, 'One item correctly added to the synchronized field values.');
 
-    foreach ($entity->{$this->fieldImageName}[$default_langcode] as $delta => $item) {
+    foreach ($entity->{$this->fieldName}[$default_langcode] as $delta => $item) {
       // When adding an item its value is copied over all the target languages,
       // thus in this case the source language needs to be used to check the
       // values instead of the target one.
       $fid_langcode = $item['fid'] != $removed_fid ? $default_langcode : $langcode;
       $value = $values[$fid_langcode][$item['fid']];
-      $source_item = $entity->{$this->fieldImageName}[$langcode][$delta];
+      $source_item = $entity->{$this->fieldName}[$langcode][$delta];
       $assert = $item['fid'] == $source_item['fid'] && $item['alt'] == $value['alt'] && $item['title'] == $value['title'];
       $this->assertTrue($assert, format_string('Field item @fid has been successfully synchronized.', array('@fid' => $item['fid'])));
     }
@@ -249,7 +222,7 @@ function testImageFieldSync() {
    */
   protected function saveEntity(EntityInterface $entity) {
     $entity->save();
-    $entity = entity_test_load($entity->id(), TRUE);
+    $entity = entity_test_mul_load($entity->id(), TRUE);
     return $entity->getBCEntity();
   }
 
diff --git b/core/modules/translation_entity/lib/Drupal/translation_entity/Tests/EntityTranslationSyncUnitTest.php a/core/modules/translation_entity/lib/Drupal/translation_entity/Tests/EntityTranslationSyncUnitTest.php
index 482a1aa..a6400a5 100644
--- b/core/modules/translation_entity/lib/Drupal/translation_entity/Tests/EntityTranslationSyncUnitTest.php
+++ a/core/modules/translation_entity/lib/Drupal/translation_entity/Tests/EntityTranslationSyncUnitTest.php
@@ -105,7 +105,7 @@ public function testFieldSync() {
       $item[$column] = $this->randomName();
     }
     $field_values[$sync_langcode][] = $item;
-    $this->synchronizer->synchronizeField($field_values, $unchanged_items, $sync_langcode, $this->langcodes, $this->synchronized);
+    $this->synchronizer->synchronizeItems($field_values, $unchanged_items, $sync_langcode, $this->langcodes, $this->synchronized);
     $result = TRUE;
     foreach ($this->unchangedFieldValues as $langcode => $items) {
       // Check that the old values are still in place.
@@ -130,7 +130,7 @@ public function testFieldSync() {
     unset($field_values[$sync_langcode][$sync_delta]);
     // Renumber deltas to start from 0.
     $field_values[$sync_langcode] = array_values($field_values[$sync_langcode]);
-    $this->synchronizer->synchronizeField($field_values, $unchanged_items, $sync_langcode, $this->langcodes, $this->synchronized);
+    $this->synchronizer->synchronizeItems($field_values, $unchanged_items, $sync_langcode, $this->langcodes, $this->synchronized);
     $result = TRUE;
     foreach ($this->unchangedFieldValues as $langcode => $items) {
       $new_delta = 0;
@@ -160,7 +160,7 @@ public function testFieldSync() {
     }
     // Renumber deltas to start from 0.
     ksort($field_values[$sync_langcode]);
-    $this->synchronizer->synchronizeField($field_values, $unchanged_items, $sync_langcode, $this->langcodes, $this->synchronized);
+    $this->synchronizer->synchronizeItems($field_values, $unchanged_items, $sync_langcode, $this->langcodes, $this->synchronized);
     $result = TRUE;
     foreach ($field_values as $langcode => $items) {
       for ($delta = 0; $delta < $this->cardinality; $delta++) {
@@ -214,7 +214,7 @@ function($delta) { return $delta === 0 || $delta === 3; },
       }
 
       $changed_items = $field_values[$sync_langcode];
-      $this->synchronizer->synchronizeField($field_values, $unchanged_items, $sync_langcode, $this->langcodes, $this->synchronized);
+      $this->synchronizer->synchronizeItems($field_values, $unchanged_items, $sync_langcode, $this->langcodes, $this->synchronized);
 
       $result = TRUE;
       foreach ($this->unchangedFieldValues as $langcode => $unchanged_items) {
@@ -246,7 +246,7 @@ public function testDifferingSyncedColumns() {
     }
 
     $changed_items = $field_values[$sync_langcode];
-    $this->synchronizer->synchronizeField($field_values, $unchanged_items, $sync_langcode, $this->langcodes, $this->synchronized);
+    $this->synchronizer->synchronizeItems($field_values, $unchanged_items, $sync_langcode, $this->langcodes, $this->synchronized);
 
     $result = TRUE;
     foreach ($this->unchangedFieldValues as $langcode => $unchanged_items) {
diff --git b/core/modules/translation_entity/lib/Drupal/translation_entity/TranslationEntityBundle.php a/core/modules/translation_entity/lib/Drupal/translation_entity/TranslationEntityBundle.php
new file mode 100644
index 0000000..617014b
--- /dev/null
+++ a/core/modules/translation_entity/lib/Drupal/translation_entity/TranslationEntityBundle.php
@@ -0,0 +1,26 @@
+<?php
+
+/**
+ * @file
+ * Contains \Drupal\translation_entity\TranslationEntityBundle.
+ */
+
+namespace Drupal\translation_entity;
+
+use Symfony\Component\DependencyInjection\ContainerBuilder;
+use Symfony\Component\DependencyInjection\Reference;
+use Symfony\Component\HttpKernel\Bundle\Bundle;
+
+/**
+ * Registers locale module's services to the container.
+ */
+class TranslationEntityBundle extends Bundle {
+
+  /**
+   * Implements \Symfony\Component\HttpKernel\Bundle\BundleInterface::build().
+   */
+  public function build(ContainerBuilder $container) {
+    $container->register('translation_entity.synchronizer', 'Drupal\translation_entity\FieldTranslationSynchronizer');
+  }
+
+}
diff --git b/core/modules/translation_entity/translation_entity.admin.css a/core/modules/translation_entity/translation_entity.admin.css
index 5f03b78..cab64f8 100644
--- b/core/modules/translation_entity/translation_entity.admin.css
+++ a/core/modules/translation_entity/translation_entity.admin.css
@@ -11,12 +11,18 @@
   font-weight: bold;
 }
 
-#language-content-settings-form table .field {
+#language-content-settings-form table .field,
+#language-content-settings-form table .column {
   width: 24%;
   padding-left: 3em;
 }
 
-#language-content-settings-form table .field label {
+#language-content-settings-form table .column {
+  padding-left: 5em;
+}
+
+#language-content-settings-form table .field label,
+#language-content-settings-form table .column label {
   font-weight: normal;
 }
 
diff --git b/core/modules/translation_entity/translation_entity.admin.inc a/core/modules/translation_entity/translation_entity.admin.inc
index aca0dd0..0e2316b 100644
--- b/core/modules/translation_entity/translation_entity.admin.inc
+++ a/core/modules/translation_entity/translation_entity.admin.inc
@@ -6,11 +6,44 @@
  */
 
 use Drupal\Core\Entity\EntityInterface;
+use Drupal\field\FieldInstance;
 
 /**
- * Implements hook_form_FORM_ID_alter() for language_content_settings_form().
+ * Returns a form element to configure field synchronization.
  *
- * @see translation_entity_form_language_content_settings_form_alter()
+ * @param array $field
+ *   A field definition array.
+ * @param \Drupal\Field\FieldInstance $instance
+ *   A field instance definition object.
+ *
+ * @return array
+ *   A form element to configure field synchronization.
+ */
+function translation_entity_field_sync_widget(array $field, FieldInstance $instance) {
+  $element = array();
+
+  if (!empty($field['settings']['column_groups']) && count($field['settings']['column_groups']) > 1) {
+    $options = array();
+    $default = array();
+
+    foreach ($field['settings']['column_groups'] as $group => $info) {
+      $options[$group] = $info['label'];
+      $default[$group] = !empty($info['translatable']) ? $group : FALSE;
+    }
+
+    $element = array(
+      '#type' => 'checkboxes',
+      '#title' => t('Translatable elements'),
+      '#options' => $options,
+      '#default_value' => !empty($instance['settings']['translation_sync']) ? $instance['settings']['translation_sync'] : $default,
+    );
+  }
+
+  return $element;
+}
+
+/**
+ * (proxied) Implements hook_form_FORM_ID_alter().
  */
 function _translation_entity_form_language_content_settings_form_alter(array &$form, array &$form_state) {
   // Inject into the content language settings the translation settings if the
@@ -48,6 +81,10 @@ function _translation_entity_form_language_content_settings_form_alter(array &$f
           '#type' => 'checkbox',
           '#default_value' => $field['translatable'],
         );
+        $column_element = translation_entity_field_sync_widget($field, $instance);
+        if ($column_element) {
+          $form['settings'][$entity_type][$bundle]['columns'][$field_name] = $column_element;
+        }
       }
     }
   }
@@ -57,6 +94,112 @@ function _translation_entity_form_language_content_settings_form_alter(array &$f
 }
 
 /**
+ * (proxied) Implements hook_preprocess_HOOK();
+ */
+function _translation_entity_preprocess_language_content_settings_table(&$variables) {
+  // Alter the 'build' variable injecting the translation settings if the user
+  // has the required permission.
+  if (!user_access('administer entity translation')) {
+    return;
+  }
+
+  $element = $variables['element'];
+  $build = &$variables['build'];
+
+  array_unshift($build['#header'], array('data' => t('Translatable'), 'class' => array('translatable')));
+  $rows = array();
+
+  foreach (element_children($element) as $bundle) {
+    $field_names = !empty($element[$bundle]['fields']) ? element_children($element[$bundle]['fields']) : array();
+    $checkbox_id = $element[$bundle]['translatable']['#id'];
+    $rows[$bundle] = $build['#rows'][$bundle];
+
+    $translatable = array(
+      'data' => $element[$bundle]['translatable'],
+      'class' => array('translatable'),
+    );
+    array_unshift($rows[$bundle]['data'], $translatable);
+
+    $rows[$bundle]['data'][1]['data']['#prefix'] = '<label for="' . $checkbox_id . '">';
+
+    foreach ($field_names as $field_name) {
+      $field_element = &$element[$bundle]['fields'][$field_name];
+      $rows[] = array(
+        'data' => array(
+          array(
+            'data' => drupal_render($field_element),
+            'class' => array('translatable'),
+          ),
+          array(
+            'data' => array(
+              '#prefix' => '<label for="' . $field_element['#id'] . '">',
+              '#suffix' => '</label>',
+              'bundle' => array(
+                '#prefix' => '<span class="element-invisible">',
+                '#suffix' => '</span> ',
+                '#markup' => check_plain($element[$bundle]['settings']['#label']),
+              ),
+              'field' => array(
+                '#markup' => check_plain($field_element['#label']),
+              ),
+            ),
+            'class' => array('field'),
+          ),
+          array(
+            'data' => '',
+            'class' => array('operations'),
+          ),
+        ),
+        'class' => array('field-settings'),
+      );
+
+      if (!empty($element[$bundle]['columns'][$field_name])) {
+        $column_element = &$element[$bundle]['columns'][$field_name];
+        foreach (element_children($column_element) as $key) {
+          $column_label = $column_element[$key]['#title'];
+          unset($column_element[$key]['#title']);
+          $rows[] = array(
+            'data' => array(
+              array(
+                'data' => drupal_render($column_element[$key]),
+                'class' => array('translatable'),
+              ),
+              array(
+                'data' => array(
+                  '#prefix' => '<label for="' . $column_element[$key]['#id'] . '">',
+                  '#suffix' => '</label>',
+                  'bundle' => array(
+                    '#prefix' => '<span class="element-invisible">',
+                    '#suffix' => '</span> ',
+                    '#markup' => check_plain($element[$bundle]['settings']['#label']),
+                  ),
+                  'field' => array(
+                    '#prefix' => '<span class="element-invisible">',
+                    '#suffix' => '</span> ',
+                    '#markup' => check_plain($field_element['#label']),
+                  ),
+                  'columns' => array(
+                    '#markup' => check_plain($column_label),
+                  ),
+                ),
+                'class' => array('column'),
+              ),
+              array(
+                'data' => '',
+                'class' => array('operations'),
+              ),
+            ),
+            'class' => array('column-settings'),
+          );
+        }
+      }
+    }
+  }
+
+  $build['#rows'] = $rows;
+}
+
+/**
  * Form validation handler for translation_entity_admin_settings_form().
  *
  * @see translation_entity_admin_settings_form_submit()
@@ -104,6 +247,11 @@ function translation_entity_form_language_content_settings_submit(array $form, a
       if (!empty($bundle_settings['fields'])) {
         foreach ($bundle_settings['fields'] as $field_name => $translatable) {
           $bundle_settings['fields'][$field_name] = $translatable && $bundle_settings['translatable'];
+          // If we have column settings and no column is translatable, no point
+          // in making the field translatable.
+          if (isset($bundle_settings['columns'][$field_name]) && !array_filter($bundle_settings['columns'][$field_name])) {
+            $bundle_settings['fields'][$field_name] = FALSE;
+          }
         }
       }
     }
diff --git b/core/modules/translation_entity/translation_entity.module a/core/modules/translation_entity/translation_entity.module
index aa51c56..f397065 100644
--- b/core/modules/translation_entity/translation_entity.module
+++ a/core/modules/translation_entity/translation_entity.module
@@ -9,7 +9,6 @@
 use Drupal\Core\Entity\EntityFormControllerInterface;
 use Drupal\Core\Entity\EntityInterface;
 use Drupal\Core\Entity\EntityNG;
-use Drupal\translation_entity\FieldTranslationSynchronizer;
 
 /**
  * Implements hook_help().
@@ -841,17 +840,12 @@ function translation_entity_form_field_ui_field_settings_form_alter(array &$form
  * Implements hook_form_FORM_ID_alter().
  */
 function translation_entity_form_field_ui_field_edit_form_alter(array &$form, array &$form_state, $form_id) {
-  if (!empty($form['#field']['settings']['translation_sync'])) {
-    $form['instance']['settings']['translation_sync'] = array(
-      '#type' => 'radios',
-      '#title' => t('Field translation'),
-      '#options' => array(
-        t('Enter different data for each language'),
-        t('Only translate textual elements'),
-      ),
-      '#default_value' => intval($form['#instance']['settings']['translation_sync']),
-      '#access' => $form['#field']['translatable'],
-    );
+  if ($form['#field']['translatable']) {
+    module_load_include('inc', 'translation_entity', 'translation_entity.admin');
+    $element = translation_entity_field_sync_widget($form['#field'], $form['#instance']);
+    if ($element) {
+      $form['instance']['settings']['translation_sync'] = $element;
+    }
   }
 }
 
@@ -872,9 +866,8 @@ function translation_entity_field_info_alter(&$info) {
  */
 function translation_entity_field_attach_presave(EntityInterface $entity) {
   if (translation_entity_enabled($entity->entityType(), $entity->bundle())) {
-    $synchronizer = new FieldTranslationSynchronizer();
     $attributes = drupal_container()->get('request')->attributes;
-    $synchronizer->synchronizeEntity($entity, $attributes->get('working_langcode'), $attributes->get('source_langcode'));
+    drupal_container()->get('translation_entity.synchronizer')->synchronizeFields($entity, $attributes->get('working_langcode'), $attributes->get('source_langcode'));
   }
 }
 
@@ -886,6 +879,7 @@ function translation_entity_element_info_alter(&$type) {
     $type['language_configuration']['#process'][] = 'translation_entity_language_configuration_element_process';
   }
 }
+
 /**
  * Returns a widget to enable entity translation per entity bundle.
  *
@@ -992,6 +986,14 @@ function translation_entity_form_language_content_settings_form_alter(array &$fo
 }
 
 /**
+ * Implements hook_preprocess_HOOK() for theme_language_content_settings_table().
+ */
+function translation_entity_preprocess_language_content_settings_table(&$variables) {
+  module_load_include('inc', 'translation_entity', 'translation_entity.admin');
+  _translation_entity_preprocess_language_content_settings_table($variables);
+}
+
+/**
  * Stores entity translation settings.
  *
  * @param array $settings
@@ -1002,81 +1004,35 @@ function translation_entity_form_language_content_settings_form_alter(array &$fo
  *     language_save_default_configuration().
  *   - fields: An associative array with field names as keys and a boolean as
  *     value, indicating field translatability.
+ *   - columns: An associative array of translation synchronization settings
+ *     keyed by field names.
  */
 function translation_entity_save_settings($settings) {
   foreach ($settings as $entity_type => $entity_settings) {
     foreach ($entity_settings as $bundle => $bundle_settings) {
+      // Store bundle translatability.
       translation_entity_set_config($entity_type, $bundle, 'enabled', $bundle_settings['translatable']);
+
+      // Store column translatability.
+      if (!empty($bundle_settings['columns'])) {
+        foreach ($bundle_settings['columns'] as $field_name => $column_settings) {
+          $field = field_info_field($field_name);
+          $instance = field_info_instance($entity_type, $field_name, $bundle);
+          if ($field['translatable']) {
+            $instance['settings']['translation_sync'] = $column_settings;
+          }
+          // If the field is untransltable we need to reset the sync settings to
+          // their defaults.
+          else {
+            unset($instance['settings']['translation_sync']);
+          }
+          field_update_instance($instance);
+        }
+      }
     }
   }
+
   // Ensure entity and menu router information are correctly rebuilt.
   entity_info_cache_clear();
   menu_router_rebuild();
 }
-
-/**
- * Implements hook_preprocess_HOOK() for theme_language_content_settings_table().
- */
-function translation_entity_preprocess_language_content_settings_table(&$variables) {
-  // Alter the 'build' variable injecting the translation settings if the user
-  // has the required permission.
-  if (!user_access('administer entity translation')) {
-    return;
-  }
-
-  $element = $variables['element'];
-  $build = &$variables['build'];
-
-  array_unshift($build['#header'], array('data' => t('Translatable'), 'class' => array('translatable')));
-  $rows = array();
-
-  foreach (element_children($element) as $bundle) {
-    $field_names = !empty($element[$bundle]['fields']) ? element_children($element[$bundle]['fields']) : array();
-    $checkbox_id = $element[$bundle]['translatable']['#id'];
-    $rows[$bundle] = $build['#rows'][$bundle];
-
-    $translatable = array(
-      'data' => $element[$bundle]['translatable'],
-      'class' => array('translatable'),
-    );
-    array_unshift($rows[$bundle]['data'], $translatable);
-
-    $rows[$bundle]['data'][1]['data']['#prefix'] = '<label for="' . $checkbox_id . '">';
-
-    foreach ($field_names as $field_name) {
-      $field = $element[$bundle]['fields'][$field_name];
-      $checkbox_id = $field['#id'];
-
-      $rows[] = array(
-        'data' => array(
-          array(
-            'data' => drupal_render($field),
-            'class' => array('translatable'),
-          ),
-          array(
-            'data' => array(
-              '#prefix' => '<label for="' . $checkbox_id . '">',
-              '#suffix' => '</label>',
-              'bundle' => array(
-                '#prefix' => '<span class="element-invisible">',
-                '#suffix' => '</span> ',
-                '#markup' => check_plain($element[$bundle]['settings']['#label']),
-              ),
-              'field' => array(
-                '#markup' => check_plain($field['#label']),
-              ),
-            ),
-            'class' => array('field'),
-          ),
-          array(
-            'data' => '',
-            'class' => array('operations'),
-          ),
-        ),
-        'class' => array('field-settings'),
-      );
-    }
-  }
-
-  $build['#rows'] = $rows;
-}

diff --git b/core/modules/translation_entity/translation_entity.admin.js a/core/modules/translation_entity/translation_entity.admin.js
index 2f9f49f..bf253a1 100644
--- b/core/modules/translation_entity/translation_entity.admin.js
+++ a/core/modules/translation_entity/translation_entity.admin.js
@@ -7,11 +7,17 @@
  */
 Drupal.behaviors.translationEntity = {
   attach: function (context) {
-    var $context = $(context);
-    // Initially hide all field rows for non translatable bundles.
-    var $inputs = $context.find('table .bundle-settings .translatable :input');
-    $inputs.filter(':not(:checked)').once('translation-entity-admin-hide', function () {
-      $(this).closest('.bundle-settings').nextUntil('.bundle-settings').hide();
+    // Initially hide all field rows for non translatable bundles and all column
+    // rows for non translatable fields.
+    $(context).find('table .bundle-settings .translatable :input').once('translation-entity-admin-hide', function () {
+      var $input = $(this);
+      var $bundleSettings = $input.closest('.bundle-settings');
+      if (!$input.is(':checked')) {
+        $bundleSettings.nextUntil('.bundle-settings').hide();
+      }
+      else {
+        $bundleSettings.nextUntil('.bundle-settings', '.field-settings').find('.translatable :input:not(:checked)').closest('.field-settings').nextUntil(':not(.column-settings)').hide();
+      }
     });
 
     // When a bundle is made translatable all of its field instances should
@@ -20,14 +26,25 @@ Drupal.behaviors.translationEntity = {
     $('body').once('translation-entity-admin-bind').on('click', 'table .bundle-settings .translatable :input', function (e) {
       var $target = $(e.target);
       var $bundleSettings = $target.closest('.bundle-settings');
-      var $fieldSettings = $bundleSettings.nextUntil('.bundle-settings');
+      var $settings = $bundleSettings.nextUntil('.bundle-settings');
+      var $fieldSettings = $settings.filter('.field-settings');
       if ($target.is(':checked')) {
         $bundleSettings.find('.operations :input[name$="[language_show]"]').attr('checked', true);
         $fieldSettings.find('.translatable :input').attr('checked', true);
-        $fieldSettings.show();
+        $settings.show();
+      }
+      else {
+        $settings.hide();
+      }
+    }).on('click', 'table .field-settings .translatable :input', function (e) {
+      var $target = $(e.target);
+      var $fieldSettings = $target.closest('.field-settings');
+      var $columnSettings = $fieldSettings.nextUntil('.field-settings, .bundle-settings');
+      if ($target.is(':checked')) {
+        $columnSettings.show();
       }
       else {
-        $fieldSettings.hide();
+        $columnSettings.hide();
       }
     });
   }